@@ -27,7 +27,7 @@ import mx4j.MX4JSystemKeys;
 import mx4j.util.Utils;
 
 /**
- * @version $Revision: 1.25 $
+ * @version $Revision: 1.26 $
  */
 public class ObjectName implements QueryExp, Serializable
 {
@@ -69,14 +69,14 @@ public class ObjectName implements QueryExp, Serializable
    private transient boolean isDomainPattern;
    private transient String canonicalName;
 
-   public ObjectName(String name) throws MalformedObjectNameException
+   public ObjectName(String name) throws NullPointerException, MalformedObjectNameException
    {
       if (name == null) throw new NullPointerException("ObjectName 'name' parameter can't be null");
       if (name.length() == 0) name = "*:*";
       parse(name);
    }
 
-   public ObjectName(String domain, Hashtable table) throws MalformedObjectNameException
+   public ObjectName(String domain, Hashtable table) throws NullPointerException, MalformedObjectNameException
    {
       if (domain == null) throw new NullPointerException("ObjectName 'domain' parameter can't be null");
       if (table == null) throw new NullPointerException("ObjectName 'table' parameter can't be null");
@@ -97,7 +97,7 @@ public class ObjectName implements QueryExp, Serializable
       init(domain, convertPropertiesToString(new TreeMap(table)), table);
    }
 
-   public ObjectName(String domain, String key, String value) throws MalformedObjectNameException
+   public ObjectName(String domain, String key, String value) throws NullPointerException, MalformedObjectNameException
    {
       if (domain == null) throw new NullPointerException("ObjectName 'domain' parameter can't be null");
       if (key == null) throw new NullPointerException("ObjectName 'key' parameter can't be null");
@@ -111,7 +111,7 @@ public class ObjectName implements QueryExp, Serializable
       init(domain, convertPropertiesToString(table), table);
    }
 
-   public boolean apply(ObjectName name)
+   public boolean apply(ObjectName name) throws NullPointerException
    {
       boolean result = false;
 
@@ -187,7 +187,7 @@ public class ObjectName implements QueryExp, Serializable
       return canonical.substring(0, index);
    }
 
-   public String getKeyProperty(String key)
+   public String getKeyProperty(String key) throws NullPointerException
    {
       Map props = getPropertiesMap();
       return (String)props.get(key);
@@ -231,7 +231,7 @@ public class ObjectName implements QueryExp, Serializable
       return isDomainPattern;
    }
 
-   public static ObjectName getInstance(ObjectName name)
+   public static ObjectName getInstance(ObjectName name) throws NullPointerException
    {
       if (name.getClass() == ObjectName.class) return name;
 
@@ -245,7 +245,7 @@ public class ObjectName implements QueryExp, Serializable
       }
    }
 
-   public static ObjectName getInstance(String name) throws MalformedObjectNameException
+   public static ObjectName getInstance(String name) throws NullPointerException, MalformedObjectNameException
    {
       if (cacheEnabled)
       {
@@ -261,17 +261,17 @@ public class ObjectName implements QueryExp, Serializable
       return new ObjectName(name);
    }
 
-   public static ObjectName getInstance(String domain, Hashtable table) throws MalformedObjectNameException
+   public static ObjectName getInstance(String domain, Hashtable table) throws NullPointerException, MalformedObjectNameException
    {
       return new ObjectName(domain, table);
    }
 
-   public static ObjectName getInstance(String domain, String key, String value) throws MalformedObjectNameException
+   public static ObjectName getInstance(String domain, String key, String value) throws NullPointerException, MalformedObjectNameException
    {
       return new ObjectName(domain, key, value);
    }
 
-   public static String quote(String value)
+   public static String quote(String value) throws NullPointerException
    {
       StringBuffer buffer = new StringBuffer("\"");
       for (int i = 0; i < value.length(); ++i)
@@ -303,7 +303,7 @@ public class ObjectName implements QueryExp, Serializable
       return buffer.toString();
    }
 
-   public static String unquote(String value) throws IllegalArgumentException
+   public static String unquote(String value) throws IllegalArgumentException, NullPointerException
    {
       int lastIndex = value.length() - 1;
       if (lastIndex < 1 || value.charAt(0) != '\"' || value.charAt(lastIndex) != '\"') throw new IllegalArgumentException("The given string is not quoted");
