@@ -46,7 +46,7 @@ import mx4j.log.Log;
 import mx4j.log.Logger;
 
 /**
- * @version $Revision: 1.27 $
+ * @version $Revision: 1.28 $
  */
 public class MLet extends URLClassLoader implements MLetMBean, MBeanRegistration, Externalizable
 {
@@ -585,7 +585,7 @@ public class MLet extends URLClassLoader implements MLetMBean, MBeanRegistration
     * Restores this MLet content from the given ObjectInput. Implementation of this method is optional,
     * and if not implemented throws an UnsupportedOperationException.
     */
-   public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException
+   public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException, UnsupportedOperationException
    {
       throw new UnsupportedOperationException("MLet.readExternal");
    }
@@ -594,7 +594,7 @@ public class MLet extends URLClassLoader implements MLetMBean, MBeanRegistration
     * Stores this MLet content in the given ObjectOutput. Implementation of this method is optional,
     * and if not implemented throws an UnsupportedOperationException.
     */
-   public void writeExternal(ObjectOutput out) throws IOException
+   public void writeExternal(ObjectOutput out) throws IOException, UnsupportedOperationException
    {
       throw new UnsupportedOperationException("MLet.writeExternal");
    }
