@@ -29,7 +29,7 @@ import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
 /**
- * @version $Revision: 1.30 $
+ * @version $Revision: 1.31 $
  */
 public class DescriptorSupport implements Descriptor
 {
@@ -102,7 +102,7 @@ public class DescriptorSupport implements Descriptor
       }
    }
 
-   public DescriptorSupport(String[] names, Object[] values)
+   public DescriptorSupport(String[] names, Object[] values) throws RuntimeOperationsException
    {
       setFields(names, values);
    }
@@ -252,7 +252,7 @@ public class DescriptorSupport implements Descriptor
       }
    }
 
-   public String toXMLString() throws RuntimeOperationsException
+   public String toXMLString()
    {
       StringBuffer buf = new StringBuffer(32);
       buf.append("<Descriptor>");
@@ -283,7 +283,7 @@ public class DescriptorSupport implements Descriptor
       }
    }
 
-   public String toString() throws RuntimeOperationsException
+   public String toString()
    {
       StringBuffer buf = new StringBuffer();
       try
