@@ -11,6 +11,7 @@ package javax.management.modelmbean;
 import java.io.Serializable;
 import java.util.Arrays;
 import java.util.List;
+
 import javax.management.Descriptor;
 import javax.management.DescriptorAccess;
 import javax.management.MBeanAttributeInfo;
@@ -23,7 +24,7 @@ import javax.management.MBeanOperationInfo;
 import javax.management.RuntimeOperationsException;
 
 /**
- * @version $Revision: 1.18 $
+ * @version $Revision: 1.19 $
  */
 // Change not needed, workaround to a TCK bug only to achieve TCK compliance
 // public class ModelMBeanInfoSupport extends MBeanInfo implements ModelMBeanInfo
@@ -275,7 +276,7 @@ public class ModelMBeanInfoSupport extends MBeanInfo implements ModelMBeanInfo,
       }
       //if (type == null) {throw new RuntimeOperationsException(new IllegalArgumentException("Descriptor type cannot be null"));}
 
-      if ("MBean".equals(type))
+      if ("mbean".equals(type))
       {
          return getMBeanDescriptor();
       }
@@ -355,11 +356,11 @@ public class ModelMBeanInfoSupport extends MBeanInfo implements ModelMBeanInfo,
       }
 
       // Now decide from the descriptor type where to find the right descriptor
-      if (descriptorType.equals("MBean"))
+      if ("mbean".equals(descriptorType))
       {
          setMBeanDescriptor(descriptor);
       }
-      else if (descriptorType.equals("attribute"))
+      else if ("attribute".equals(descriptorType))
       {
          MBeanAttributeInfo[] attrs = modelMBeanAttributes;
          if (attrs != null)
@@ -376,7 +377,7 @@ public class ModelMBeanInfoSupport extends MBeanInfo implements ModelMBeanInfo,
             }
          }
       }
-      else if (descriptorType.equals("notification"))
+      else if ("notification".equals(descriptorType))
       {
          MBeanNotificationInfo[] notifs = modelMBeanNotifications;
          if (notifs != null)
@@ -393,7 +394,7 @@ public class ModelMBeanInfoSupport extends MBeanInfo implements ModelMBeanInfo,
             }
          }
       }
-      else if (descriptorType.equals("constructor"))
+      else if ("constructor".equals(descriptorType))
       {
          MBeanConstructorInfo[] ctors = modelMBeanConstructors;
          if (ctors != null)
@@ -410,7 +411,7 @@ public class ModelMBeanInfoSupport extends MBeanInfo implements ModelMBeanInfo,
             }
          }
       }
-      else if (descriptorType.equals("operation")/* || descriptorType.equals("getter") || descriptorType.equals("setter")*/)
+      else if ("operation".equals(descriptorType)/* || descriptorType.equals("getter") || descriptorType.equals("setter")*/)
       {
          MBeanOperationInfo[] opers = modelMBeanOperations;
          if (opers != null)
@@ -675,7 +676,7 @@ public class ModelMBeanInfoSupport extends MBeanInfo implements ModelMBeanInfo,
       // Go with the Javadoc to mimic the RI (WkH)
       String[] names = new String[]{"name", "descriptorType", "displayName", "persistPolicy", "log", "export", "visibility"};
       int index = getClassName().lastIndexOf('.') + 1;
-      Object[] values = new Object[]{getClassName().substring(index), "MBean", getClassName(), "Never", "F", "F", "1"};
+      Object[] values = new Object[]{getClassName().substring(index), "mbean", getClassName(), "Never", "F", "F", "1"};
       return new DescriptorSupport(names, values);
    }
 
