@@ -51,7 +51,7 @@ import mx4j.persist.PersisterMBean;
 import mx4j.util.Utils;
 
 /**
- * @version $Revision: 1.22 $
+ * @version $Revision: 1.23 $
  */
 public class RequiredModelMBean implements ModelMBean, MBeanRegistration, NotificationEmitter
 {
@@ -275,12 +275,12 @@ public class RequiredModelMBean implements ModelMBean, MBeanRegistration, Notifi
       if (logger.isEnabledFor(Logger.DEBUG)) logger.debug("Listener " + listener + " for attribute " + attributeName + " removed successfully, handback is " + handback);
    }
 
-   public void removeNotificationListener(NotificationListener listener) throws RuntimeOperationsException, ListenerNotFoundException
+   public void removeNotificationListener(NotificationListener listener) throws ListenerNotFoundException
    {
       m_generalBroadcaster.removeNotificationListener(listener);
    }
 
-   public void removeNotificationListener(NotificationListener listener, NotificationFilter filter, Object handback) throws RuntimeOperationsException, ListenerNotFoundException
+   public void removeNotificationListener(NotificationListener listener, NotificationFilter filter, Object handback) throws ListenerNotFoundException
    {
       m_generalBroadcaster.removeNotificationListener(listener, filter, handback);
    }
