@@ -11,7 +11,7 @@ package javax.management.openmbean;
 import java.util.Collection;
 
 /**
- * @version $Revision: 1.5 $
+ * @version $Revision: 1.6 $
  */
 public interface CompositeData
 {
@@ -21,9 +21,9 @@ public interface CompositeData
 
    public boolean equals(Object object);
 
-   public Object get(String key) throws InvalidKeyException;
+   public Object get(String key);
 
-   public Object[] getAll(String[] keys) throws javax.management.openmbean.InvalidKeyException;
+   public Object[] getAll(String[] keys);
 
    public CompositeType getCompositeType();
 
