@@ -23,7 +23,7 @@ import mx4j.log.Log;
 import mx4j.log.Logger;
 
 /**
- * @version $Revision: 1.14 $
+ * @version $Revision: 1.17 $
  */
 public class RelationSupport implements RelationSupportMBean, MBeanRegistration
 {
@@ -32,7 +32,7 @@ public class RelationSupport implements RelationSupportMBean, MBeanRegistration
    private ObjectName m_relationServiceObjectName;
    private MBeanServer m_server;
    private RelationServiceMBean m_proxy;
-   private Boolean m_isInRelationService = null;
+   private Boolean m_isInRelationService = Boolean.FALSE;
    private Map m_roleNameToRole = new HashMap();
 
    public RelationSupport(String relationId,
@@ -49,16 +49,16 @@ public class RelationSupport implements RelationSupportMBean, MBeanRegistration
                                                                                     m_relationServiceObjectName,
                                                                                     RelationServiceMBean.class,
                                                                                     false);
-      m_isInRelationService = new Boolean(false);
    }
 
    private void init(String relationId, ObjectName relationServiceObjectName, String relationTypeName, RoleList roleList)
            throws InvalidRoleValueException
    {
       if (relationId == null) throw new IllegalArgumentException("Illegal Null RelationId");
-      if (relationServiceObjectName == null) throw new IllegalArgumentException("Illegal Null RelatiobService ObjectName");
+      if (relationServiceObjectName == null) throw new IllegalArgumentException("Illegal Null RelationService ObjectName");
       if (relationTypeName == null) throw new IllegalArgumentException("Illegal Null RelationTypeName");
-      if (roleList == null) throw new IllegalArgumentException("Illegal Null RoleList");
+      if (roleList == null) roleList = new RoleList();
+
       m_relationId = relationId;
       m_relationServiceObjectName = relationServiceObjectName;
       m_relationTypeName = relationTypeName;
@@ -274,7 +274,7 @@ public class RelationSupport implements RelationSupportMBean, MBeanRegistration
             roleUnresolvedList.add(new RoleUnresolved(roleName, currentRole.getRoleValue(), problemType));
          }
       }
-      return (new RoleResult(roleList, roleUnresolvedList));
+      return (new RoleResult(newRoleList, roleUnresolvedList));
    }
 
    // check role conforms to defined cardinality
@@ -390,13 +390,13 @@ public class RelationSupport implements RelationSupportMBean, MBeanRegistration
 
    public Boolean isInRelationService()
    {
-      return (new Boolean(m_isInRelationService.booleanValue()));
+      return m_isInRelationService;
    }
 
    public void setRelationServiceManagementFlag(Boolean isHandledByRelationService) throws IllegalArgumentException
    {
       if (isHandledByRelationService == null) throw new IllegalArgumentException("Null flag");
-      m_isInRelationService = new Boolean(isHandledByRelationService.booleanValue());
+      m_isInRelationService = isHandledByRelationService;
    }
 
    public ObjectName preRegister(MBeanServer server,
