@@ -12,13 +12,13 @@ import java.io.Serializable;
 import java.util.List;
 
 /**
- * @version $Revision: 1.5 $
+ * @version $Revision: 1.6 $
  */
 public interface RelationType extends Serializable
 {
    public String getRelationTypeName();
 
-   public RoleInfo getRoleInfo(String roleInfoName) throws RoleInfoNotFoundException;
+   public RoleInfo getRoleInfo(String roleInfoName) throws IllegalArgumentException, RoleInfoNotFoundException;
 
    public List getRoleInfos();
 }
\ No newline at end of file
