@@ -14,7 +14,7 @@ import java.util.List;
 import javax.management.ObjectName;
 
 /**
- * @version $Revision: 1.10 $
+ * @version $Revision: 1.11 $
  */
 public class RoleUnresolved implements Serializable
 {
@@ -47,7 +47,7 @@ public class RoleUnresolved implements Serializable
       return roleValue == null ? null : new ArrayList(roleValue);
    }
 
-   public void setRoleName(String name)
+   public void setRoleName(String name) throws IllegalArgumentException
    {
       if (name == null) throw new IllegalArgumentException("Role Name cannot be null");
       roleName = name;
@@ -70,7 +70,7 @@ public class RoleUnresolved implements Serializable
       }
    }
 
-   public void setProblemType(int type)
+   public void setProblemType(int type) throws IllegalArgumentException
    {
       if (!(RoleStatus.isRoleStatus(type)))
       {
