@@ -9,14 +9,13 @@
 package javax.management.remote;
 
 import java.io.IOException;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 
 import mx4j.remote.ProviderFactory;
 
 /**
- * @version $Revision: 1.10 $
+ * @version $Revision: 1.11 $
  */
 public class JMXConnectorFactory
 {
@@ -43,7 +42,7 @@ public class JMXConnectorFactory
    public static JMXConnector newJMXConnector(JMXServiceURL url, Map env) throws IOException
    {
       Map envCopy = env == null ? new HashMap() : new HashMap(env);
-      JMXConnectorProvider provider = ProviderFactory.newJMXConnectorProvider(url, envCopy);
-      return provider.newJMXConnector(url, Collections.unmodifiableMap(envCopy));
+      JMXConnector connector = ProviderFactory.newJMXConnector(url, envCopy);
+      return connector;
    }
 }
