@@ -9,15 +9,15 @@
 package javax.management.remote;
 
 import java.io.IOException;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
+
 import javax.management.MBeanServer;
 
 import mx4j.remote.ProviderFactory;
 
 /**
- * @version $Revision: 1.6 $
+ * @version $Revision: 1.7 $
  */
 public class JMXConnectorServerFactory
 {
@@ -33,7 +33,7 @@ public class JMXConnectorServerFactory
    public static JMXConnectorServer newJMXConnectorServer(JMXServiceURL url, Map environment, MBeanServer server) throws IOException
    {
       Map env = environment == null ? new HashMap() : new HashMap(environment);
-      JMXConnectorServerProvider provider = ProviderFactory.newJMXConnectorServerProvider(url, env);
-      return provider.newJMXConnectorServer(url, Collections.unmodifiableMap(env), server);
+      JMXConnectorServer connector = ProviderFactory.newJMXConnectorServer(url, env, server);
+      return connector;
    }
 }
