@@ -21,6 +21,7 @@ import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
+
 import javax.management.Attribute;
 import javax.management.AttributeList;
 import javax.management.AttributeNotFoundException;
@@ -53,9 +54,7 @@ import javax.management.ObjectName;
 import javax.management.OperationsException;
 import javax.management.QueryExp;
 import javax.management.ReflectionException;
-import javax.management.RuntimeErrorException;
 import javax.management.RuntimeOperationsException;
-import javax.management.StandardMBean;
 import javax.management.loading.ClassLoaderRepository;
 import javax.management.loading.PrivateClassLoader;
 
@@ -93,7 +92,7 @@ import mx4j.util.Utils;
  * the MBean type: if the MBean is a dynamic MBean, the call is dispatched directly; if the MBean is a standard
  * MBean an {@link MBeanInvoker} is delegated to invoke on the MBean instance.
  *
- * @version $Revision: 1.24 $
+ * @version $Revision: 1.31 $
  */
 public class MX4JMBeanServer implements MBeanServer
 {
@@ -129,7 +128,7 @@ public class MX4JMBeanServer implements MBeanServer
          sm.checkPermission(new MBeanServerPermission("newMBeanServer"));
       }
 
-      if (defaultDomain == null) defaultDomain = "";
+      if (defaultDomain == null) defaultDomain = "DefaultDomain";
       this.defaultDomain = defaultDomain;
 
       if (delegate == null) throw new JMRuntimeException("Delegate can't be null");
@@ -510,6 +509,10 @@ public class MX4JMBeanServer implements MBeanServer
    public void addNotificationListener(ObjectName observed, NotificationListener listener, NotificationFilter filter, Object handback)
            throws InstanceNotFoundException
    {
+      if (observed == null)
+      {
+         throw new RuntimeOperationsException(new IllegalArgumentException("ObjectName cannot be null"));
+      }
       if (listener == null)
       {
          throw new RuntimeOperationsException(new IllegalArgumentException("NotificationListener cannot be null"));
@@ -692,7 +695,27 @@ public class MX4JMBeanServer implements MBeanServer
       try
       {
          Class cls = getModifiableClassLoaderRepository().loadClass(className);
-         MBeanMetaData metadata = instantiateImpl(className, cls.getClassLoader(), objectName, parameters, args);
+         MBeanMetaData metadata;
+
+         // todo we should change the interceptor stack so that an InstantiationException
+         //      can be thrown directly and handled appropriately. However, I think
+         //      that should wait until a major release so am hacking this in here
+         try
+         {
+            metadata = instantiateImpl(className, cls.getClassLoader(), objectName, parameters, args);
+         }
+         catch (ReflectionException e)
+         {
+            Exception target = e.getTargetException();
+            if (target instanceof InstantiationException)
+            {
+               throw new NotCompliantMBeanException();
+            }
+            else
+            {
+               throw e;
+            }
+         }
 
          registerImpl(metadata, false);
 
@@ -796,60 +819,20 @@ public class MX4JMBeanServer implements MBeanServer
 
       MBeanServerInterceptor head = getHeadInterceptor();
 
+      head.registration(metadata, MBeanServerInterceptor.PRE_REGISTER);
+
+      // The MBean implementor could have replaced the ObjectName with a subclass that is not secure, secure it again
+      metadata.setObjectName(secureObjectName(metadata.getObjectName()));
+
+      int postRegisterFlag = MBeanServerInterceptor.POST_REGISTER_FALSE;
       try
       {
-         // With this call, the MBean implementor can replace the ObjectName with a subclass that is not secure, secure it again
-         head.registration(metadata, MBeanServerInterceptor.PRE_REGISTER);
-         metadata.setObjectName(secureObjectName(metadata.getObjectName()));
-
-//         metadata.instance = new ObjectInstance(metadata.name, metadata.info.getClassName());
-
          register(metadata, privileged);
-
-         head.registration(metadata, MBeanServerInterceptor.POST_REGISTER_TRUE);
+         postRegisterFlag = MBeanServerInterceptor.POST_REGISTER_TRUE;
       }
-      catch (Throwable x)
+      finally
       {
-         try
-         {
-            head.registration(metadata, MBeanServerInterceptor.POST_REGISTER_FALSE);
-         }
-         catch (MBeanRegistrationException ignored)
-         {/* Ignore this one to rethrow the other one */
-         }
-
-         if (x instanceof SecurityException)
-         {
-            throw (SecurityException)x;
-         }
-         else if (x instanceof InstanceAlreadyExistsException)
-         {
-            throw (InstanceAlreadyExistsException)x;
-         }
-         else if (x instanceof MBeanRegistrationException)
-         {
-            throw (MBeanRegistrationException)x;
-         }
-         else if (x instanceof RuntimeOperationsException)
-         {
-            throw (RuntimeOperationsException)x;
-         }
-         else if (x instanceof JMRuntimeException)
-         {
-            throw (JMRuntimeException)x;
-         }
-         else if (x instanceof Exception)
-         {
-            throw new MBeanRegistrationException((Exception)x);
-         }
-         else if (x instanceof Error)
-         {
-            throw new MBeanRegistrationException(new RuntimeErrorException((Error)x));
-         }
-         else
-         {
-            throw new ImplementationException();
-         }
+         head.registration(metadata, postRegisterFlag);
       }
 
       Object mbean = metadata.getMBean();
@@ -940,36 +923,16 @@ public class MX4JMBeanServer implements MBeanServer
 
       MBeanMetaData metadata = findMBeanMetaData(objectName);
 
-      try
-      {
-         MBeanServerInterceptor head = getHeadInterceptor();
-         head.registration(metadata, MBeanServerInterceptor.PRE_DEREGISTER);
+      MBeanServerInterceptor head = getHeadInterceptor();
+      head.registration(metadata, MBeanServerInterceptor.PRE_DEREGISTER);
+      unregister(metadata);
 
-         unregister(metadata);
+      getHeadInterceptor().registration(metadata, MBeanServerInterceptor.POST_DEREGISTER);
 
-         getHeadInterceptor().registration(metadata, MBeanServerInterceptor.POST_DEREGISTER);
-
-         Object mbean = metadata.getMBean();
-         if (mbean instanceof ClassLoader && !(mbean instanceof PrivateClassLoader))
-         {
-            getModifiableClassLoaderRepository().removeClassLoader((ClassLoader)mbean);
-         }
-      }
-      catch (MBeanRegistrationException x)
+      Object mbean = metadata.getMBean();
+      if (mbean instanceof ClassLoader && !(mbean instanceof PrivateClassLoader))
       {
-         throw x;
-      }
-      catch (SecurityException x)
-      {
-         throw x;
-      }
-      catch (Exception x)
-      {
-         throw new MBeanRegistrationException(x);
-      }
-      catch (Error x)
-      {
-         throw new MBeanRegistrationException(new RuntimeErrorException(x));
+         getModifiableClassLoaderRepository().removeClassLoader((ClassLoader)mbean);
       }
    }
 
@@ -1087,11 +1050,38 @@ public class MX4JMBeanServer implements MBeanServer
 
    public String[] getDomains()
    {
+      SecurityManager sm = System.getSecurityManager();
+      if (sm != null)
+      {
+         sm.checkPermission(new MBeanPermission(null, null, null, "getDomains"));
+      }
+      Set keys;
       synchronized (domains)
       {
-         Set keys = domains.keySet();
-         return (String[])keys.toArray(new String[keys.size()]);
+         keys = new HashSet(domains.keySet());
       }
+      if (sm != null)
+      {
+         for (Iterator i = keys.iterator(); i.hasNext();)
+         {
+            String domain = (String)i.next();
+            try
+            {
+               ObjectName name = new ObjectName(domain, "x", "x");
+               sm.checkPermission(new MBeanPermission(null, null, name, "getDomains"));
+            }
+            catch (SecurityException e)
+            {
+               i.remove();
+               continue;
+            }
+            catch (MalformedObjectNameException e)
+            {
+               throw new ImplementationException("Unexpected MalformedObjectNameException for registered domain: " + domain);
+            }
+         }
+      }
+      return (String[])keys.toArray(new String[keys.size()]);
    }
 
    public Integer getMBeanCount()
@@ -1157,29 +1147,22 @@ public class MX4JMBeanServer implements MBeanServer
       objectName = secureObjectName(objectName);
 
       MBeanMetaData metadata = findMBeanMetaData(objectName);
+      String infoClassName = metadata.getMBeanInfo().getClassName();
 
       SecurityManager sm = System.getSecurityManager();
       if (sm != null)
       {
-         sm.checkPermission(new MBeanPermission(metadata.getMBeanInfo().getClassName(), "-", objectName, "isInstanceOf"));
+         sm.checkPermission(new MBeanPermission(infoClassName, "-", objectName, "isInstanceOf"));
       }
+      if (className.equals(infoClassName)) return true;
 
       try
       {
          ClassLoader loader = metadata.getClassLoader();
          if (loader == null) loader = Thread.currentThread().getContextClassLoader();
          Class cls = loader.loadClass(className);
-
-         Object mbean = metadata.getMBean();
-         if (mbean instanceof StandardMBean)
-         {
-            Object impl = ((StandardMBean)mbean).getImplementation();
-            return cls.isInstance(impl);
-         }
-         else
-         {
-            return cls.isInstance(mbean);
-         }
+         Class infoClass = loader.loadClass(infoClassName);
+         return cls.isAssignableFrom(infoClass);
       }
       catch (ClassNotFoundException x)
       {
