@@ -33,7 +33,7 @@ import mx4j.log.Log;
 import mx4j.server.MX4JMBeanServer;
 
 /**
- * @version $Revision: 1.4 $
+ * @version $Revision: 1.5 $
  */
 public class LocalSecurityManagerTest extends SecurityManagerTestCase
 {
@@ -264,7 +264,7 @@ public class LocalSecurityManagerTest extends SecurityManagerTestCase
 
       // Check also the overloaded version, we need an MLet
       String mletClassName = "javax.management.loading.MLet";
-      ObjectName name = new ObjectName(":mbean=mlet");
+      ObjectName name = new ObjectName(server.getDefaultDomain(), "mbean", "mlet");
       resetPermissions();
       addPermission(new MBeanPermission(mletClassName, "instantiate, registerMBean"));
       addPermission(new RuntimePermission("createClassLoader"));
@@ -324,7 +324,7 @@ public class LocalSecurityManagerTest extends SecurityManagerTestCase
       MBeanServer server = MBeanServerFactory.newMBeanServer();
 
       MBeanServerDelegate mbean = new MBeanServerDelegate();
-      ObjectName name = new ObjectName(":name=test");
+      ObjectName name = new ObjectName(server.getDefaultDomain(), "name", "test");
 
       try
       {
@@ -367,7 +367,7 @@ public class LocalSecurityManagerTest extends SecurityManagerTestCase
 
       // Needed to create an MLet, which is a ClassLoader
       addPermission(new RuntimePermission("createClassLoader"));
-      ObjectName name = new ObjectName(":mbean=mlet");
+      ObjectName name = new ObjectName(server.getDefaultDomain(), "mbean", "mlet");
       MLet mlet = new MLet();
       addPermission(new MBeanPermission(mlet.getClass().getName(), "registerMBean"));
       server.registerMBean(mlet, name);
