@@ -9,13 +9,14 @@
 package test.javax.management;
 
 import java.util.Hashtable;
+
 import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
 
 import test.MX4JTestCase;
 
 /**
- * @version $Revision: 1.13 $
+ * @version $Revision: 1.15 $
  */
 public class ObjectNameTest extends MX4JTestCase
 {
@@ -244,7 +245,57 @@ public class ObjectNameTest extends MX4JTestCase
 
       try
       {
-         new ObjectName("domain:key=\"newLinePresent" + '\n' + "\"");
+         new ObjectName("domain:key=\"quotedNewLinePresent" + '\n' + "\"");
+         fail("Wrong ObjectName");
+      }
+      catch (MalformedObjectNameException x)
+      {
+      }
+
+      try
+      {
+         // Just one quote
+         new ObjectName("domain:key=\"");
+         fail("Wrong ObjectName");
+      }
+      catch (MalformedObjectNameException x)
+      {
+      }
+
+      try
+      {
+         // Just one quote with a space
+         new ObjectName("domain:key=\" ");
+         fail("Wrong ObjectName");
+      }
+      catch (MalformedObjectNameException x)
+      {
+      }
+
+      try
+      {
+         // Just one quote with a chars
+         new ObjectName("domain:key=\"unterminatedQuote");
+         fail("Wrong ObjectName");
+      }
+      catch (MalformedObjectNameException x)
+      {
+      }
+
+      try
+      {
+         // Just one quote with an escaped quote at the end
+         new ObjectName("domain:key=\"\\\"");
+         fail("Wrong ObjectName");
+      }
+      catch (MalformedObjectNameException x)
+      {
+      }
+
+      try
+      {
+         // Just one quote with a chars and an escaped quote at the end
+         new ObjectName("domain:key=\"unterminatedQuote\\\"");
          fail("Wrong ObjectName");
       }
       catch (MalformedObjectNameException x)
@@ -395,6 +446,15 @@ public class ObjectNameTest extends MX4JTestCase
       catch (MalformedObjectNameException x)
       {
       }
+
+      try
+      {
+         new ObjectName("domain", "x", "\"unterminated");
+         fail("Wrong ObjectName");
+      }
+      catch (MalformedObjectNameException x)
+      {
+      }
    }
 
    public void testValidQuotedObjectName() throws Exception
