@@ -15,6 +15,7 @@ import java.net.URL;
 import java.util.List;
 import java.util.Random;
 import java.util.Set;
+import java.util.Iterator;
 import javax.management.MBeanRegistration;
 import javax.management.MBeanServer;
 import javax.management.ObjectInstance;
@@ -31,7 +32,7 @@ import mx4j.server.DefaultClassLoaderRepository;
 import test.MX4JTestCase;
 
 /**
- * @version $Revision: 1.18 $
+ * @version $Revision: 1.19 $
  */
 public class MLetTest extends MX4JTestCase
 {
@@ -672,6 +673,15 @@ public class MLetTest extends MX4JTestCase
       assertTrue(tempLibrary.length() > 0);
    }
 
+   public void testDefaultMletName() throws Exception {
+      MBeanServer mbServer = newMBeanServer();
+      MLet mlet = new MLet();
+      ObjectName mletName = new ObjectName(mbServer.getDefaultDomain(), "type", "MLet");
+      assertFalse(mbServer.isRegistered(mletName));
+      assertEquals(mletName, mbServer.registerMBean(mlet, null).getObjectName());
+      assertTrue(mbServer.isRegistered(mletName));
+   }
+
    public interface SimpleMBean
    {
    }
