@@ -9,26 +9,8 @@
 package test.javax.management.modelmbean;
 
 import java.util.List;
-import javax.management.Attribute;
-import javax.management.AttributeList;
-import javax.management.Descriptor;
-import javax.management.InstanceNotFoundException;
-import javax.management.MBeanException;
-import javax.management.MBeanParameterInfo;
-import javax.management.MBeanServer;
-import javax.management.MBeanServerFactory;
-import javax.management.NotCompliantMBeanException;
-import javax.management.Notification;
-import javax.management.NotificationListener;
-import javax.management.ObjectName;
-import javax.management.RuntimeOperationsException;
-import javax.management.modelmbean.DescriptorSupport;
-import javax.management.modelmbean.ModelMBean;
-import javax.management.modelmbean.ModelMBeanAttributeInfo;
-import javax.management.modelmbean.ModelMBeanInfoSupport;
-import javax.management.modelmbean.ModelMBeanNotificationInfo;
-import javax.management.modelmbean.ModelMBeanOperationInfo;
-import javax.management.modelmbean.RequiredModelMBean;
+import javax.management.*;
+import javax.management.modelmbean.*;
 
 import test.MX4JTestCase;
 import test.MutableBoolean;
@@ -36,7 +18,7 @@ import test.MutableInteger;
 import test.javax.management.modelmbean.support.ModelMBeanTarget;
 
 /**
- * @version $Revision: 1.13 $
+ * @version $Revision: 1.14 $
  */
 public class RequiredModelMBeanTest extends MX4JTestCase
 {
@@ -80,19 +62,21 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       try
       {
          m_server.registerMBean(rmmb, name);
-         fail("RequireModelMBean cannot be registered, ModelMBeanInfo is missing");
+         m_server.unregisterMBean(name);
       }
       catch (NotCompliantMBeanException x)
       {
+         fail("Default RequireModelMBean cannot be registered");
       }
 
       try
       {
          m_server.createMBean(RequiredModelMBean.class.getName(), name, null);
-         fail("RequireModelMBean cannot be registered, ModelMBeanInfo is missing");
+         m_server.unregisterMBean(name);
       }
       catch (NotCompliantMBeanException x)
       {
+         fail("Default RequireModelMBean cannot be created");
       }
 
       rmmb = (RequiredModelMBean)m_server.instantiate(RequiredModelMBean.class.getName(), null);
@@ -372,11 +356,13 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       rmmb.addAttributeChangeNotificationListener(dummyListener, null, null);
       rmmb.removeAttributeChangeNotificationListener(dummyListener, null);
 
-      // Change the persist policy
+      // Change the persist policy - have to unregeister to call setModelMBeanInfo
+      m_server.unregisterMBean(name);
       attrDescr1.setField("persistPolicy", "OnUpdate");
       info.setDescriptor(attrDescr1, "attribute");
       rmmb.setModelMBeanInfo(info);
       storeTester.set(false);
+      m_server.registerMBean(rmmb, name);
 
       value = "SET_SECOND_TIME";
       attribute = new Attribute(attrName1, value);
@@ -387,7 +373,8 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       // There are persistence settings, check that store was called
       assertTrue("Store should have been called", storeTester.get());
 
-      // Now remove setMethod
+      // Now remove setMethod - again we have to unregister
+      m_server.unregisterMBean(name);
       names1 = new String[]{"name", "descriptorType", "value", "iterable", "displayName", "getMethod", "currencyTimeLimit"};
       // changed to match the actual behaviour indicated in the specs about currencyTimeLimit
       // currencyTimeLimit is now -1
@@ -397,6 +384,7 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       info.setDescriptor(attrDescr1, "attribute");
       rmmb.setModelMBeanInfo(info);
       storeTester.set(false);
+      m_server.registerMBean(rmmb, name);
 
       value = "SET_THIRD_TIME";
       attribute = new Attribute(attrName1, value);
@@ -417,6 +405,7 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       }
 
       // Test attribute that takes array as parameters
+      m_server.unregisterMBean(name);
       String attrName = "ArrayAttribute";
       String[] names = new String[]{"name", "descriptorType", "value", "iterable", "displayName", "getMethod", "setMethod", "currencyTimeLimit"};
       // changed to match the actual behaviour indicated in the specs about currencyTimeLimit
@@ -427,6 +416,7 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       ModelMBeanAttributeInfo attrInfo = new ModelMBeanAttributeInfo(attrName, new String[0].getClass().getName(), "", true, true, false, attrDescr);
       info = new ModelMBeanInfoSupport(ModelMBeanTarget.class.getName(), "", new ModelMBeanAttributeInfo[]{attrInfo}, null, null, null);
       rmmb.setModelMBeanInfo(info);
+      m_server.registerMBean(rmmb, name);
 
       String[] v = new String[]{"one", "two"};
       attribute = new Attribute(attrName, v);
@@ -543,12 +533,15 @@ public class RequiredModelMBeanTest extends MX4JTestCase
          assertEquals("Returned value is different: " + obj, args[i], obj);
       }
 
+      m_server.unregisterMBean(name);
       ModelMBeanTarget.TargetBean target = new ModelMBeanTarget.TargetBean();
       operDescr.setField("targetObject", target);
       operDescr.setField("targetObjectType", "ObjectReference");
 
       info.setDescriptor(operDescr, "operation");
       rmmb.setModelMBeanInfo(info);
+      m_server.registerMBean(rmmb, name);
+
       list = (List)m_server.invoke(name, operation, args, params);
 
       // Test that was not called
@@ -587,16 +580,18 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       // Bug #940161 Required ModelMBean methods are not invoked
       m_server.invoke(name, "setManagedResource", new Object[]{new ModelMBeanTarget(new MutableInteger(0)), "ObjectReference"}, new String[]{Object.class.getName(), String.class.getName()});
       m_server.invoke(name, "store", new Object[0], new String[0]);
-      m_server.invoke(name, "load", new Object[0], new String[0]);
       m_server.invoke(name, "sendNotification", new Object[]{"generic"}, new String[]{String.class.getName()});
 
       // Now specify setManagedResource as an operation in the MMBI
+      m_server.unregisterMBean(name);
       String operation = "setManagedResource";
       MBeanParameterInfo paramInfo1 = new MBeanParameterInfo("resource", Object.class.getName(), "");
       MBeanParameterInfo paramInfo2 = new MBeanParameterInfo("type", String.class.getName(), "");
       ModelMBeanOperationInfo operInfo = new ModelMBeanOperationInfo(operation, "", new MBeanParameterInfo[]{paramInfo1, paramInfo2}, null, ModelMBeanOperationInfo.ACTION, null);
       info = new ModelMBeanInfoSupport(ModelMBeanTarget.class.getName(), "", null, null, new ModelMBeanOperationInfo[]{operInfo}, null);
       mmb.setModelMBeanInfo(info);
+      m_server.registerMBean(mmb, name);
+
       // Spec says I must be able to invoke it
       Object target = new ModelMBeanTarget(new MutableInteger(0));
       m_server.invoke(name, operation, new Object[]{target, "ObjectReference"}, new String[]{Object.class.getName(), String.class.getName()});
@@ -609,10 +604,12 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       ModelMBeanNotificationInfo notification[] = new ModelMBeanNotificationInfo[1];
       notification[0] = new ModelMBeanNotificationInfo(new String[]{ModelMBeanTarget.class.getName() + ".notification"}, "name", "");
 
-      ModelMBeanInfoSupport info = new ModelMBeanInfoSupport(ModelMBeanTarget.class.getName(), "", null, null, null, notification);
+      ModelMBeanAttributeInfo attributeInfo = new ModelMBeanAttributeInfo("MutableContent", String.class.getName(), "", true, true, false);
+      ModelMBeanInfoSupport info = new ModelMBeanInfoSupport(ModelMBeanTarget.class.getName(), "", new ModelMBeanAttributeInfo[]{attributeInfo}, null, null, notification);
 
       RequiredModelMBean rmmb = new RequiredModelMBean();
       rmmb.setModelMBeanInfo(info);
+      rmmb.setManagedResource(new ModelMBeanTarget(new MutableInteger(0)), "objectReference");
       m_server.registerMBean(rmmb, name);
 
       Object listenerHandback = new Object();
@@ -621,7 +618,7 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       m_server.addNotificationListener(name, listener, null, listenerHandback);
 
       rmmb.sendNotification("generic notification");
-      assertEquals("jmx.modelmbean.general", listener.type);
+      assertEquals("jmx.modelmbean.generic", listener.type);
       assertEquals("generic notification", listener.message);
       assertSame(listenerHandback, listener.handback);
 
@@ -629,6 +626,24 @@ public class RequiredModelMBeanTest extends MX4JTestCase
       assertEquals("my.type", listener.type);
       assertEquals("a message", listener.message);
       assertSame(listenerHandback, listener.handback);
+
+      m_server.setAttribute(name, new Attribute("MutableContent", "Hello World"));
+      assertEquals("jmx.attribute.change", listener.type);
+   }
+
+   public void testGetNotificationInfo() throws Exception
+   {
+      RequiredModelMBean rmmb = new RequiredModelMBean();
+      MBeanNotificationInfo[] notificationInfos = rmmb.getNotificationInfo();
+      assertEquals(2, notificationInfos.length);
+
+      ModelMBeanNotificationInfo notification[] = new ModelMBeanNotificationInfo[1];
+      notification[0] = new ModelMBeanNotificationInfo(new String[]{ModelMBeanTarget.class.getName() + ".notification"}, "name", "");
+
+      ModelMBeanInfoSupport info = new ModelMBeanInfoSupport(ModelMBeanTarget.class.getName(), "", null, null, null, notification);
+      rmmb.setModelMBeanInfo(info);
+      notificationInfos = rmmb.getNotificationInfo();
+      assertEquals(3, notificationInfos.length);
    }
 
    public static class StoreTesterRMMB extends RequiredModelMBean
