@@ -287,6 +287,55 @@ public class CounterMonitorTest extends MonitorTestCase
       }
    }
 
+   public void testShutDownMonitorThread() throws Exception
+   {
+      MBeanServer server = newMBeanServer();
+      CounterMonitor monitor = (CounterMonitor)createMonitor();
+      server.registerMBean(monitor, ObjectName.getInstance(":service=monitor"));
+
+      Counter counter = new Counter();
+      ObjectName counterName = ObjectName.getInstance(":mbean=counter");
+      server.registerMBean(counter, counterName);
+
+      long period = 1000;
+      monitor.addObservedObject(counterName);
+      monitor.setGranularityPeriod(period);
+      monitor.setObservedAttribute("IntegerCounter");
+      Integer initThreshold = new Integer(3);
+      monitor.setInitThreshold(initThreshold);
+      monitor.setNotify(true);
+      // No modulus, no offset
+
+      counter.setIntegerCounter(initThreshold.intValue() - 1);
+
+      final MutableObject monitorThread = new MutableObject(null);
+      monitor.addNotificationListener(new NotificationListener()
+      {
+         public void handleNotification(Notification notification, Object handback)
+         {
+            monitorThread.set(Thread.currentThread());
+         }
+      }, null, null);
+      monitor.start();
+
+      // Below threshold, no notifications should be sent
+      sleep(period * 3);
+
+      // Above threshold, just one notification should be sent
+      counter.setIntegerCounter(initThreshold.intValue() + 1);
+      sleep(period * 3);
+
+      Thread thread = (Thread)monitorThread.get();
+      assertNotNull(thread);
+      assertNotSame(thread, Thread.currentThread());
+
+      monitor.stop();
+
+      sleep(period * 3);
+
+      assertFalse(thread.isAlive());
+   }
+
    public interface CounterMBean
    {
       public Object getObjectCounter();
