@@ -31,7 +31,7 @@ import javax.management.relation.RoleStatus;
 import junit.framework.TestCase;
 
 /**
- * @version $Revision: 1.17 $
+ * @version $Revision: 1.18 $
  */
 public class RelationServiceTest extends TestCase
 {
@@ -221,11 +221,11 @@ public class RelationServiceTest extends TestCase
       try
       {
          m_relationService.removeRelationType("invalidRelationType_notCreated");
-         // expected should not fail
+         fail("Expected a RelationTypeNotFoundException to be thrown");
       }
       catch (RelationTypeNotFoundException expected)
       {
-         fail("RelationType does not exist but no exception expected");
+         // ok
       }
       catch (Exception e)
       {
