@@ -15,6 +15,7 @@ import java.io.StringReader;
 import java.net.Socket;
 import java.util.ArrayList;
 import java.util.Hashtable;
+
 import javax.management.MBeanServer;
 import javax.management.MBeanServerFactory;
 import javax.management.ObjectName;
@@ -28,7 +29,7 @@ import mx4j.tools.config.DefaultConfigurationBuilder;
 import test.MX4JTestCase;
 
 /**
- * @version $Revision: 1.6 $
+ * @version $Revision: 1.7 $
  */
 public class ConfigurationLoaderTest extends MX4JTestCase
 {
@@ -252,6 +253,25 @@ public class ConfigurationLoaderTest extends MX4JTestCase
       MBeanServerFactory.releaseMBeanServer((MBeanServer)list.get(0));
    }
 
+   public void testCallElementWithObjectArgument() throws Exception
+   {
+      MBeanServer server = newMBeanServer();
+      String config =
+              "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>" +
+              "<configuration>" +
+              "  <startup>" +
+              "    <object objectid=\"list\">" +
+              "      <new classname=\"java.util.ArrayList\" />" +
+              "    </object>" +
+              "    <call refobjectid=\"list\" method=\"add\">" +
+              "      <arg type=\"object\">A String</arg>" +
+              "    </call>" +
+              "  </startup>" +
+              "</configuration>";
+      ConfigurationLoader loader = new ConfigurationLoader(server);
+      loader.startup(new StringReader(config));
+   }
+
    public void testCallElementObjectInvocation() throws Exception
    {
       MBeanServer server = newMBeanServer();
