@@ -22,6 +22,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+
 import javax.management.Attribute;
 import javax.management.MBeanServer;
 import javax.management.MalformedObjectNameException;
@@ -33,7 +34,7 @@ import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;
 
 /**
- * @version $Revision: 1.7 $
+ * @version $Revision: 1.8 $
  */
 public class DefaultConfigurationBuilder implements ConfigurationBuilder
 {
@@ -403,7 +404,7 @@ public class DefaultConfigurationBuilder implements ConfigurationBuilder
       public Class getJavaType() throws ConfigurationException
       {
          if (STRING_TYPE.equalsIgnoreCase(type)) return String.class;
-         if (OBJECT_TYPE.equalsIgnoreCase(type)) return Object.class;
+         if (OBJECT_TYPE.equalsIgnoreCase(type)) return java.lang.Object.class;
          if (BOOLEAN_TYPE.equalsIgnoreCase(type)) return boolean.class;
          if (BYTE_TYPE.equalsIgnoreCase(type)) return byte.class;
          if (CHAR_TYPE.equalsIgnoreCase(type)) return char.class;
