@@ -10,6 +10,7 @@ package mx4j.tools.remote.caucho.hessian;
 
 import java.io.InputStream;
 import java.io.OutputStream;
+
 import javax.servlet.ServletException;
 
 import mx4j.tools.remote.caucho.CauchoInput;
@@ -18,7 +19,7 @@ import mx4j.tools.remote.caucho.CauchoService;
 import mx4j.tools.remote.caucho.CauchoServlet;
 
 /**
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
  */
 public class HessianServlet extends CauchoServlet
 {
@@ -27,7 +28,12 @@ public class HessianServlet extends CauchoServlet
    public void init() throws ServletException
    {
       super.init();
-      service = new CauchoService("hessian");
+      service = createService();
+   }
+
+   protected CauchoService createService()
+   {
+      return new CauchoService("hessian");
    }
 
    public void destroy()
