@@ -89,7 +89,7 @@ public class HTTPConnector extends AbstractJMXConnector
       return connection;
    }
 
-   public RemoteNotificationClientHandler getRemoteNotificationClientHandler()
+   protected RemoteNotificationClientHandler getRemoteNotificationClientHandler()
    {
       return notificationHandler;
    }
