@@ -25,7 +25,7 @@ import org.mortbay.jetty.servlet.ServletHttpContext;
 /**
  * Jetty's implementation of WebContainer interface
  *
- * @version $Revision: 1.5 $
+ * @version $Revision: 1.6 $
  */
 public class JettyWebContainer implements WebContainer
 {
@@ -111,7 +111,9 @@ public class JettyWebContainer implements WebContainer
    {
       Logger logger = getLogger();
       if (logger.isEnabledFor(Logger.DEBUG)) logger.debug("Configuring Jetty with a default listener on port " + url.getPort());
-      getServer().addListener(":" + url.getPort());
+      String host = url.getHost();
+      if (host == null) host = "";
+      getServer().addListener(host + ":" + url.getPort());
    }
 
    public void stop() throws IOException
