@@ -9,21 +9,25 @@
 package mx4j.tools.remote.provider.hessian;
 
 import java.io.IOException;
+import java.net.MalformedURLException;
 import java.util.Map;
+
 import javax.management.MBeanServer;
 import javax.management.remote.JMXConnectorServer;
 import javax.management.remote.JMXConnectorServerProvider;
 import javax.management.remote.JMXServiceURL;
 
-import mx4j.tools.remote.caucho.hessian.HessianConnectorServer;
+import mx4j.tools.remote.http.HTTPConnectorServer;
 
 /**
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.5 $
  */
 public class ServerProvider implements JMXConnectorServerProvider
 {
    public JMXConnectorServer newJMXConnectorServer(JMXServiceURL url, Map environment, MBeanServer server) throws IOException
    {
-      return new HessianConnectorServer(url, environment, server);
+      String protocol = url.getProtocol();
+      if (!"hessian".equals(protocol)) throw new MalformedURLException("Wrong protocol " + protocol + " for provider " + this);
+      return new HTTPConnectorServer(url, environment, server);
    }
 }
