@@ -9,7 +9,9 @@
 package mx4j.tools.remote.provider.soap;
 
 import java.io.IOException;
+import java.net.MalformedURLException;
 import java.util.Map;
+
 import javax.management.remote.JMXConnector;
 import javax.management.remote.JMXConnectorProvider;
 import javax.management.remote.JMXServiceURL;
@@ -19,12 +21,14 @@ import mx4j.tools.remote.soap.SOAPConnector;
 /**
  * SOAP Connector Client Provider
  *
- * @version $Revision: 1.5 $
+ * @version $Revision: 1.6 $
  */
 public class ClientProvider implements JMXConnectorProvider
 {
    public JMXConnector newJMXConnector(JMXServiceURL url, Map environment) throws IOException
    {
+      String protocol = url.getProtocol();
+      if (!"soap".equals(protocol)) throw new MalformedURLException("Wrong protocol " + protocol + " for provider " + this);
       return new SOAPConnector(url, environment);
    }
-}
\ No newline at end of file
+}
